@@ -1,6 +1,6 @@
 package HTML::Index;
 
-$VERSION = '0.16';
+$VERSION = '0.17';
 
 #------------------------------------------------------------------------------
 #
@@ -96,7 +96,7 @@ parentheses, and logical operators (OR, AND, NOT).
 
 =head1 AUTHOR
 
-Ave Wrigley <Ave.Wrigley@itn.co.uk>
+Ave Wrigley <ave.wrigley@gmail.com>
 
 =head1 COPYRIGHT
 
